# Authors

## PyKEEN Project Team

- [Charles Tapley Hoyt](https://github.com/cthoyt)
- [Laurent Vermue](https://github.com/lvermue)
- [Max Berrendorf](https://github.com/mberr)
- [Mehdi Ali](https://github.com/mali-git)
- [Sahand Sharifzadeh](https://github.com/sharifza)

## Contributors

- [Daniel Domingo Fernández](https://github.com/ddomingof)
- [Michael F. Schönitzer](https://github.com/Nudin)
- [Maximilian Hünemörder](https://github.com/huenemoerder)
- [Michael Galkin](https://github.com/migalkin)
- [Felix Hamann](https://github.com/kantholtz)
- [Sankranti Joshi](https://github.com/sunny1401)

See also: https://github.com/pykeen/pykeen/graphs/contributors
